package Bundle::Locale::CLDR::Melanesia;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Melanesia

=head1 CONTENTS

Locale::CLDR::Locales::Fr 0.44.1

Locale::CLDR::Locales::Pis 0.44.1

Locale::CLDR::Locales::Tpi 0.44.1

Locale::CLDR::Locales::Fr::Latn 0.44.1

Locale::CLDR::Locales::Pis::Latn 0.44.1

Locale::CLDR::Locales::Tpi::Latn 0.44.1

Locale::CLDR::Locales::En::Latn::Fj 0.44.1

Locale::CLDR::Locales::En::Latn::Pg 0.44.1

Locale::CLDR::Locales::En::Latn::Sb 0.44.1

Locale::CLDR::Locales::En::Latn::Vu 0.44.1

Locale::CLDR::Locales::Fr::Latn::Nc 0.44.1

Locale::CLDR::Locales::Fr::Latn::Vu 0.44.1

Locale::CLDR::Locales::En::Latn::001 0.44.1

Locale::CLDR::Locales::Pis::Latn::Sb 0.44.1

Locale::CLDR::Locales::Tpi::Latn::Pg 0.44.1


=cut

1;

